@@ -120,18 +120,20 @@ def _prepare_bteq_command(
     bteq_session_encoding: str,
     timeout_rc: int,
 ) -> list[str]:
-    bteq_core_cmd = ["bteq"]
-    if bteq_session_encoding:
-        bteq_core_cmd.append(f" -e {bteq_script_encoding}")
-        bteq_core_cmd.append(f" -c {bteq_session_encoding}")
-    bteq_core_cmd.append('"')
-    bteq_core_cmd.append(f".SET EXITONDELAY ON MAXREQTIME {timeout}")
+    cmd = ["bteq"]
+    if bteq_session_encoding and bteq_script_encoding:
+        cmd.extend(["-e", bteq_script_encoding])
+        cmd.extend(["-c", bteq_session_encoding])
+
+    script_parts = [f".SET EXITONDELAY ON MAXREQTIME {timeout}"]
     if timeout_rc is not None and timeout_rc >= 0:
-        bteq_core_cmd.append(f" RC {timeout_rc}")
-    bteq_core_cmd.append(";")
+        script_parts.append(f"RC {timeout_rc}")
+    script_parts.append(";")
     # Airflow doesn't display the script of BTEQ in UI but only in log so WIDTH is 500 enough
-    bteq_core_cmd.append(" .SET WIDTH 500;")
-    return bteq_core_cmd
+    script_parts.append(".SET WIDTH 500;")
+
+    cmd.append(" ".join(script_parts))
+    return cmd
 
 
 def prepare_bteq_command_for_remote_execution(
@@ -141,9 +143,9 @@ def prepare_bteq_command_for_remote_execution(
     timeout_rc: int,
 ) -> str:
     """Prepare the BTEQ command with necessary parameters."""
-    bteq_core_cmd = _prepare_bteq_command(timeout, bteq_script_encoding, bteq_session_encoding, timeout_rc)
-    bteq_core_cmd.append('"')
-    return " ".join(bteq_core_cmd)
+    cmd = _prepare_bteq_command(timeout, bteq_script_encoding, bteq_session_encoding, timeout_rc)
+    cmd.append('"')
+    return " ".join(cmd)
 
 
 def prepare_bteq_command_for_local_execution(
@@ -152,16 +154,14 @@ def prepare_bteq_command_for_local_execution(
     bteq_script_encoding: str,
     bteq_session_encoding: str,
     timeout_rc: int,
-) -> str:
+) -> list[str]:
     """Prepare the BTEQ command with necessary parameters."""
-    bteq_core_cmd = _prepare_bteq_command(timeout, bteq_script_encoding, bteq_session_encoding, timeout_rc)
+    cmd = _prepare_bteq_command(timeout, bteq_script_encoding, bteq_session_encoding, timeout_rc)
     host = conn["host"]
     login = conn["login"]
     password = conn["password"]
-    bteq_core_cmd.append(f" .LOGON {host}/{login},{password}")
-    bteq_core_cmd.append('"')
-    bteq_command_str = " ".join(bteq_core_cmd)
-    return bteq_command_str
+    cmd[-1] += f" .LOGON {host}/{login},{password}"
+    return cmd
 
 
 def is_valid_file(file_path: str) -> bool:
